#!/bin/zsh

# Copyright 2014 Paul Hänsch
#
# This file is part of Confetti.
# 
# Confetti is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Confetti is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with Confetti.  If not, see <http://www.gnu.org/licenses/>. 

export LC_ALL=de_DE.UTF-8
DBG_ENABLED=false
DBG_FILE=/dev/stderr

# this program is supposed to be symlinked into a http root directory
# we will use the http root as object storage (data directory) and call sub
# programs from the directory in which the real executable resides
# therefore we need to identify the code and data directories _EXEC and _DATA
call="$0"
real="$(readlink -f $call)"
_EXEC="$(dirname "$real")"  #execution directory
_DATA="$(dirname "$call")"  #storage directory

# put debug options in the local.opts file
[ -r "$_DATA/local.opts" ] && . "$_DATA/local.opts"

# basic functions
debug() { #change to false to disable debugging
  if [ "$DBG_ENABLED" = true -a -n "$*" ]; then
    echo -E "$*" >>"$DBG_FILE"
  elif [ "$DBG_ENABLED" = true -a -z "$*" ]; then
    tee -a "$DBG_FILE"
  elif [ -z "$*" ]; then
    cat
  fi
}

die() {
  debug "$*"
  echo -E "$*" >>/dev/stderr
  exit 1
}

# create directories for object storage
[ -w "$_DATA" ] && [ -d "$_DATA" ] || die "storage directory must be writable"

for each in "$_DATA"/{vcard,ical,cache,temp,mappings}; do
  [ ! -e "$each" ] && mkdir "$each"
  [ -w "$each" ] && [ -d "$each" ] || die "storage $each must be a writable directory"
done
touch "$_DATA/mappings/attendance"

# create htaccess file
[ -f .htaccess ] || cat >.htaccess <<EOF
Options		+ExecCGI
AddHandler	cgi-script .cgi
DirectoryIndex	index.cgi
EOF
[ -f .htaccess ] || die "no htaccess file present and unable to create one"

. "$_EXEC/cgi.sh"
cgi_get

. "$_EXEC/constants.sh"

if [ -n "$_GET[\"action\"]" ]; then
  . "$_EXEC/action.sh"
elif [ -n "$_GET[\"export\"]" ]; then
  . "$_EXEC/export.sh"
else
  . "$_EXEC/page.sh"
fi
